@@ -158,10 +158,10 @@
 
 #
 #==============================================================================
-from pysat.formula import IDPool, WCNFPlus
-from pysat.examples.rc2 import RC2, RC2Stratified
-from pysat.examples.lbx import LBX
-from pysat.examples.mcsls import MCSls
+from ..formula import IDPool, WCNFPlus
+from .rc2 import RC2, RC2Stratified
+from .lbx import LBX
+from .mcsls import MCSls
 import six
 
 
