@@ -131,9 +131,9 @@ import getopt
 import itertools
 from math import copysign
 import os
-from pysat.formula import CNFPlus, WCNFPlus, IDPool
-from pysat.card import ITotalizer
-from pysat.solvers import Solver, SolverNames
+from ..formula import CNFPlus, WCNFPlus, IDPool
+from ..card import ITotalizer
+from ..solvers import Solver, SolverNames
 import re
 import six
 from six.moves import range
